@@ -62,7 +62,10 @@ public class Example2 {
 	latex += "\\end{array}";
 
 	TeXFormula formula = new TeXFormula(latex);
-	TeXIcon icon = formula.createTeXIcon(TeXConstants.STYLE_DISPLAY, 20);
+	// Note: Old interface for creating icons:
+	//TeXIcon icon = formula.createTeXIcon(TeXConstants.STYLE_DISPLAY, 20);
+	// Note: New interface using builder pattern (inner class):
+	TeXIcon icon = formula.new TeXIconBuilder().setStyle(TeXConstants.STYLE_DISPLAY).setSize(20).build();
 	icon.setInsets(new Insets(5, 5, 5, 5));
 
 	BufferedImage image = new BufferedImage(icon.getIconWidth(), icon.getIconHeight(), BufferedImage.TYPE_INT_ARGB);
