@@ -47,19 +47,24 @@ public class HorizontalBox extends Box {
     public HorizontalBox(Box b, float w, int alignment) {
         if (w != Float.POSITIVE_INFINITY) {
             float rest = w - b.getWidth();
-            if (alignment == TeXConstants.ALIGN_CENTER || alignment == TeXConstants.ALIGN_NONE) {
-                StrutBox s = new StrutBox(rest / 2, 0, 0, 0);
-                add(s);
-                add(b);
-                add(s);
-            } else if (alignment == TeXConstants.ALIGN_LEFT) {
-                add(b);
-                add(new StrutBox(rest, 0, 0, 0));
-            } else if (alignment == TeXConstants.ALIGN_RIGHT) {
-                add(new StrutBox(rest, 0, 0, 0));
-                add(b);
-            } else
-                add(b);
+	    if (rest > 0) {
+		if (alignment == TeXConstants.ALIGN_CENTER || alignment == TeXConstants.ALIGN_NONE) {
+		    StrutBox s = new StrutBox(rest / 2, 0, 0, 0);
+		    add(s);
+		    add(b);
+		    add(s);
+		} else if (alignment == TeXConstants.ALIGN_LEFT) {
+		    add(b);
+		    add(new StrutBox(rest, 0, 0, 0));
+		} else if (alignment == TeXConstants.ALIGN_RIGHT) {
+		    add(new StrutBox(rest, 0, 0, 0));
+		    add(b);
+		} else {
+		    add(b);
+		}
+	    } else {
+		add(b);
+	    }
         } else {
             add(b);
         }
