@@ -39,8 +39,8 @@ import java.util.List;
  */
 public class MatrixAtom extends Atom {
 
-    public static SpaceAtom hsep = new SpaceAtom(TeXConstants.UNIT_EM, 2.0f, 0.0f, 0.0f);
-    public static SpaceAtom semihsep = new SpaceAtom(TeXConstants.UNIT_EM, 1.0f, 0.0f, 0.0f);
+    public static SpaceAtom hsep = new SpaceAtom(TeXConstants.UNIT_EM, 1f, 0.0f, 0.0f);
+    public static SpaceAtom semihsep = new SpaceAtom(TeXConstants.UNIT_EM, 0.5f, 0.0f, 0.0f);
     public static SpaceAtom vsep_in = new SpaceAtom(TeXConstants.UNIT_EX, 0.0f, 1f, 0.0f);
     public static SpaceAtom vsep_ext_top = new SpaceAtom(TeXConstants.UNIT_EX, 0.0f, 0.4f, 0.0f);
     public static SpaceAtom vsep_ext_bot = new SpaceAtom(TeXConstants.UNIT_EX, 0.0f, 0.4f, 0.0f);
@@ -64,6 +64,7 @@ public class MatrixAtom extends Atom {
     private boolean isFl;
     private int type;
     private boolean isPartial;
+    private boolean spaceAround;
 
     private static SpaceAtom align = new SpaceAtom(TeXConstants.MEDMUSKIP);
 
@@ -71,13 +72,22 @@ public class MatrixAtom extends Atom {
      * Creates an empty matrix
      *
      */
-    public MatrixAtom(boolean isPartial, ArrayOfAtoms array, String options) {
+    public MatrixAtom(boolean isPartial, ArrayOfAtoms array, String options, boolean spaceAround) {
         this.isPartial = isPartial;
         this.matrix = array;
         this.type = ARRAY;
+        this.spaceAround = spaceAround;
         parsePositions(new StringBuffer(options));
     }
 
+    /**
+     * Creates an empty matrix
+     *
+     */
+    public MatrixAtom(boolean isPartial, ArrayOfAtoms array, String options) {
+        this(isPartial, array, options, false);
+    }
+
     /**
      * Creates an empty matrix
      *
@@ -87,9 +97,14 @@ public class MatrixAtom extends Atom {
     }
 
     public MatrixAtom(boolean isPartial, ArrayOfAtoms array, int type) {
+        this(isPartial, array, type, false);
+    }
+
+    public MatrixAtom(boolean isPartial, ArrayOfAtoms array, int type, boolean spaceAround) {
         this.isPartial = isPartial;
         this.matrix = array;
         this.type = type;
+        this.spaceAround = spaceAround;
 
         if (type != MATRIX && type != SMALLMATRIX) {
             position = new int[matrix.col];
@@ -108,9 +123,14 @@ public class MatrixAtom extends Atom {
     }
 
     public MatrixAtom(boolean isPartial, ArrayOfAtoms array, int type, int alignment) {
+        this(isPartial, array, type, alignment, true);
+    }
+
+    public MatrixAtom(boolean isPartial, ArrayOfAtoms array, int type, int alignment, boolean spaceAround) {
         this.isPartial = isPartial;
         this.matrix = array;
         this.type = type;
+        this.spaceAround = spaceAround;
 
         position = new int[matrix.col];
         for (int i = 0; i < matrix.col; i++) {
@@ -183,6 +203,9 @@ public class MatrixAtom extends Atom {
                 len = opt.length();
                 pos--;
                 break;
+            case ' ':
+            case '\t':
+                break;
             default :
                 lposition.add(TeXConstants.ALIGN_CENTER);
             }
@@ -224,7 +247,11 @@ public class MatrixAtom extends Atom {
                 arr[1] = new StrutBox(0.0f, 0.0f, 0.0f, 0.0f);
                 i = 2;
             }
-            arr[0] = semihsep.createBox(env);
+            if (spaceAround) {
+                arr[0] = semihsep.createBox(env);
+            } else {
+                arr[0] = new StrutBox(0.0f, 0.0f, 0.0f, 0.0f);
+            }
             arr[col] = arr[0];
             Hsep = hsep.createBox(env);
             for (; i < col; i++) {
