@@ -64,13 +64,11 @@ public class SpaceAtom extends Atom {
         public float getPixelConversion(TeXEnvironment env);
     }
 
-    // TODO: UNIT_EM and UNIT_EX yield the same converters ??
-
     private static UnitConversion[] unitConversions = new UnitConversion[] {
 
         new UnitConversion() {//EM
             public float getPixelConversion(TeXEnvironment env) {
-                return env.getTeXFont().getXHeight(env.getStyle(), env.getLastFontId());
+                return env.getTeXFont().getEM(env.getStyle());
             }
         },
 
@@ -250,9 +248,9 @@ public class SpaceAtom extends Atom {
             else {
                 int bl = blankType < 0 ? -blankType : blankType;
                 Box b;
-                if (bl == TeXConstants.THINMUSKIP)
-                    b = Glue.get(TeXConstants.TYPE_INNER, TeXConstants.TYPE_ORDINARY, env);
-                else if (bl == TeXConstants.MEDMUSKIP)
+                if (bl == TeXConstants.THINMUSKIP) {
+                    b = Glue.get(TeXConstants.TYPE_INNER, TeXConstants.TYPE_BIG_OPERATOR, env);
+                } else if (bl == TeXConstants.MEDMUSKIP)
                     b = Glue.get(TeXConstants.TYPE_BINARY_OPERATOR, TeXConstants.TYPE_BIG_OPERATOR, env);
                 else
                     b = Glue.get(TeXConstants.TYPE_RELATION, TeXConstants.TYPE_BIG_OPERATOR, env);
