@@ -81,7 +81,7 @@ import java.lang.Character.UnicodeBlock;
  */
 public class TeXFormula {
 
-    public static final String VERSION = "1.0.2";
+    public static final String VERSION = "1.0.3";
 
     public static final int SERIF = 0;
     public static final int SANSSERIF = 1;
@@ -166,6 +166,10 @@ public class TeXFormula {
         tfsp.parseSymbolToFormulaMappings(symbolFormulaMappings, symbolTextMappings);
     }
 
+    public static boolean isRegisteredBlock(Character.UnicodeBlock block) {
+	return externalFontMap.get(block) != null;
+    }
+
     public static FontInfos getExternalFont(Character.UnicodeBlock block) {
         FontInfos infos = externalFontMap.get(block);
         if (infos == null) {
