@@ -1107,7 +1107,11 @@ public class TeXParser {
 
             String symbolName = TeXFormula.symbolMappings[c];
             if (symbolName == null && (TeXFormula.symbolFormulaMappings == null || TeXFormula.symbolFormulaMappings[c] == null)) {
-                TeXFormula.FontInfos fontInfos = TeXFormula.getExternalFont(block);
+		TeXFormula.FontInfos fontInfos = null;
+		boolean isLatin = Character.UnicodeBlock.BASIC_LATIN.equals(block);
+		if ((isLatin && TeXFormula.isRegisteredBlock(Character.UnicodeBlock.BASIC_LATIN)) || !isLatin) {
+		    fontInfos = TeXFormula.getExternalFont(block);
+		}
                 if (fontInfos != null) {
                     if (oneChar) {
                         return new JavaFontRenderingAtom(Character.toString(c), fontInfos);
@@ -1376,7 +1380,7 @@ public class TeXParser {
      * @param com the command's name
      * @return the validity of the name
      */
-    public boolean isValidName(String com) {
+    public final boolean isValidName(String com) {
         if (com == null || "".equals(com)) {
             return false;
         }
@@ -1402,11 +1406,11 @@ public class TeXParser {
      * @param com the command's name
      * @return the validity of the name
      */
-    public boolean isValidCharacterInCommand(char ch) {
+    public final boolean isValidCharacterInCommand(char ch) {
         return Character.isLetter(ch) || (atIsLetter != 0 && ch == '@');
     }
 
-    private void skipWhiteSpace() {
+    private final void skipWhiteSpace() {
         char c;
         while (pos < len) {
             c = parseString.charAt(pos);
