@@ -37,7 +37,7 @@ public class tcaronAtom extends Atom {
     }
     
     public Box createBox(TeXEnvironment env) {
-	CharBox A = new CharBox(env.getTeXFont().getChar("jlatexmathapos", env.getStyle()));
+	CharBox A = new CharBox(env.getTeXFont().getChar("textapos", env.getStyle()));
 	CharBox t = new CharBox(env.getTeXFont().getChar('t', "mathnormal", env.getStyle()));
 	HorizontalBox hb = new HorizontalBox(t);
 	hb.add(new SpaceAtom(TeXConstants.UNIT_EM, -0.3f, 0, 0).createBox(env));
